import 'package:basic_ui/src/providers/theme_provider.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:provider/provider.dart';
import 'package:flutter_color/flutter_color.dart';

import '../../basic_ui.dart';

class BasicApp extends StatelessWidget {
  const BasicApp({
    Key? key,
    this.title = '',
    this.fontFamily = 'Open Sans',
    this.home,
    this.theme,
  }) : super(key: key);

  final String title;
  final String fontFamily;
  final Widget? home;
  final BasicTheme? theme;

  @override
  Widget build(BuildContext context) {
    return ChangeNotifierProvider(
      create: (_) => ThemeProvider(),
      child: _App(
        fontFamily: fontFamily,
        home: home,
        theme: theme,
      ),
    );
  }
}

class _App extends HookWidget {
  const _App({
    Key? key,
    required this.fontFamily,
    this.home,
    this.theme,
  }) : super(key: key);

  final String fontFamily;
  final Widget? home;
  final BasicTheme? theme;

  @override
  Widget build(BuildContext context) {
    context.read<ThemeProvider>().changeTheme(this.theme);
    final theme = context.watch<ThemeProvider>().theme;

    final primaryDarkColor = theme.primaryColor.darker(10);
    final primaryLightColor = theme.primaryColor.lighter(10);

    return MaterialApp(
      title: 'Daily Habit',
      theme: ThemeData(
        accentColor: theme.primaryColor,
        primaryColor: theme.primaryColor,
        primaryColorDark: primaryDarkColor,
        primaryColorLight: primaryLightColor,
        visualDensity: VisualDensity.adaptivePlatformDensity,
        textSelectionTheme: TextSelectionThemeData(
          selectionColor: primaryLightColor,
          selectionHandleColor: primaryDarkColor,
          cursorColor: theme.primaryColor,
        ),
        buttonColor: theme.primaryColor,
        fontFamily: fontFamily,
        textButtonTheme: TextButtonThemeData(
          style: ButtonStyle(
            shape: MaterialStateProperty.all<RoundedRectangleBorder>(
              const RoundedRectangleBorder(),
            ),
            overlayColor: MaterialStateColor.resolveWith(
              (states) => theme.borderColor,
            ),
          ),
        ),
        elevatedButtonTheme: ElevatedButtonThemeData(
          style: ButtonStyle(
            shape: MaterialStateProperty.all<RoundedRectangleBorder>(
              const RoundedRectangleBorder(),
            ),
            backgroundColor: MaterialStateColor.resolveWith(
              (states) => theme.primaryColor,
            ),
            overlayColor: MaterialStateColor.resolveWith(
              (states) => primaryDarkColor,
            ),
            elevation: MaterialStateProperty.resolveWith((states) => 0),
          ),
        ),
        outlinedButtonTheme: OutlinedButtonThemeData(
          style: ButtonStyle(
            shape: MaterialStateProperty.all<RoundedRectangleBorder>(
              RoundedRectangleBorder(side: BorderSide(color: theme.fontColor)),
            ),
            overlayColor: MaterialStateColor.resolveWith(
              (states) => theme.borderColor,
            ),
          ),
        ),
      ),
      home: home,
    );
  }
}
