import 'package:basic_ui/src/providers/theme_provider.dart';
import 'package:basic_ui/src/widgets/basic_color.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:provider/provider.dart';

import '../utils/get_luminance.dart';
import 'basic_text.dart';

class BasicAppBar extends StatelessWidget implements PreferredSizeWidget {
  const BasicAppBar({
    Key? key,
    required this.title,
    this.actions,
    this.backgroundColor,
    this.enableSearchBar = false,
    this.searchBarPlaceHolder,
    this.onClear,
    this.onSubmitted,
    this.tabs,
    this.elevation,
  }) : super(key: key);

  final String title;
  final List<Widget>? actions;
  final Color? backgroundColor;
  final bool enableSearchBar;
  final String? searchBarPlaceHolder;
  final Function? onClear;
  final Function(String)? onSubmitted;
  final List<Widget>? tabs;
  final double? elevation;

  List<Widget> _createActionMenu(TextEditingController searchBarController) {
    return [
      IconButton(
        icon: const Icon(Icons.close),
        onPressed: () {
          searchBarController.clear();
          if (onClear != null) onClear!();
        },
      )
    ];
  }

  @override
  Widget build(BuildContext context) {
    final theme = context.watch<ThemeProvider>().theme;

    final searchBarController = TextEditingController();
    final backgroundColor = this.backgroundColor ?? theme.primaryColor;
    Color textColor = BasicColor.fontColor;
    final double luminance = backgroundColor.getLuminance();

    luminance > 0.5
        ? textColor = BasicColor.fontColor
        : textColor = Colors.white;

    TabBar? tabBar;
    if (tabs != null) tabBar = TabBar(tabs: tabs!);

    return AppBar(
      title: !enableSearchBar
          ? BasicText(
              title,
              color: textColor,
              fontWeight: FontWeight.w600,
              fontSize: 17,
            )
          : Theme(
              data: Theme.of(context).copyWith(
                textSelectionTheme: const TextSelectionThemeData().copyWith(
                  cursorColor: Colors.white,
                ),
              ),
              child: TextField(
                autofocus: true,
                controller: searchBarController,
                decoration: InputDecoration(
                  border: InputBorder.none,
                  focusedBorder: InputBorder.none,
                  enabledBorder: InputBorder.none,
                  errorBorder: InputBorder.none,
                  disabledBorder: InputBorder.none,
                  hintText: searchBarPlaceHolder,
                  hintStyle: TextStyle(color: textColor.withAlpha(200)),
                ),
                onSubmitted: onSubmitted,
                textInputAction: TextInputAction.search,
                style: TextStyle(color: textColor),
              ),
            ),
      actions:
          !enableSearchBar ? actions : _createActionMenu(searchBarController),
      elevation: elevation ?? theme.appBarElevation,
      brightness: luminance > 0.5 ? Brightness.light : Brightness.dark,
      backgroundColor: backgroundColor,
      iconTheme: IconThemeData(color: textColor),
      bottom: tabBar,
    );
  }

  @override
  Size get preferredSize => Size.fromHeight(
      tabs == null ? kToolbarHeight : kToolbarHeight + kTextTabBarHeight);
}
