import 'package:basic_ui/src/models/basic_theme.dart';
import 'package:basic_ui/src/providers/theme_provider.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

import '../utils/get_luminance.dart';
import 'basic_text.dart';
import 'basic_color.dart';

enum BasicButtonVariant { primary, outlined, text }

class BasicButton extends StatelessWidget {
  const BasicButton(
    this.text, {
    Key? key,
    required this.onPressed,
    this.variant = BasicButtonVariant.primary,
  }) : super(key: key);

  final String text;
  final void Function()? onPressed;
  final BasicButtonVariant variant;

  @override
  Widget build(BuildContext context) {
    final theme = context.watch<ThemeProvider>().theme;

    switch (variant) {
      case BasicButtonVariant.primary:
        return _PrimaryButton(onPressed: onPressed, text: text, theme: theme);
      case BasicButtonVariant.outlined:
        return _OutlinedButton(onPressed: onPressed, text: text, theme: theme);
      case BasicButtonVariant.text:
        return _TextButton(theme: theme, text: text);

      default:
        return _PrimaryButton(onPressed: onPressed, text: text, theme: theme);
    }
  }
}

class _TextButton extends StatelessWidget {
  const _TextButton({
    Key? key,
    this.onPressed,
    required this.theme,
    required this.text,
  }) : super(key: key);

  final void Function()? onPressed;
  final BasicTheme theme;
  final String text;

  @override
  Widget build(BuildContext context) {
    return TextButton(
      onPressed: onPressed,
      child: BasicText(
        text,
        color: theme.primaryColor,
        variant: BasicTextVariant.label,
      ),
    );
  }
}

class _OutlinedButton extends StatelessWidget {
  const _OutlinedButton({
    Key? key,
    this.onPressed,
    required this.text,
    required this.theme,
  }) : super(key: key);

  final void Function()? onPressed;
  final String text;
  final BasicTheme theme;

  @override
  Widget build(BuildContext context) {
    return OutlinedButton(
      onPressed: onPressed,
      child: BasicText(
        text,
        color: theme.fontColor,
        variant: BasicTextVariant.label,
      ),
    );
  }
}

class _PrimaryButton extends StatelessWidget {
  const _PrimaryButton({
    Key? key,
    this.onPressed,
    required this.text,
    required this.theme,
  }) : super(key: key);

  final void Function()? onPressed;
  final String text;
  final BasicTheme theme;

  @override
  Widget build(BuildContext context) {
    return ElevatedButton(
      onPressed: onPressed,
      child: BasicText(
        text,
        color: theme.primaryColor.getLuminance() > 0.5
            ? BasicColor.fontColor
            : Colors.white,
        variant: BasicTextVariant.label,
      ),
    );
  }
}
