import 'package:basic_ui/src/providers/theme_provider.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:provider/provider.dart';

import '../models/basic_theme.dart';

class BasicList extends HookWidget {
  const BasicList({
    Key? key,
    required this.itemCount,
    required this.itemBuilder,
    this.disableDivider = false,
    this.padding,
  }) : super(key: key);

  final int itemCount;
  final Widget Function(BuildContext context, int index) itemBuilder;
  final bool disableDivider;
  final EdgeInsetsGeometry? padding;

  List<Widget> buildItem(BuildContext context, BasicTheme themeProviderState) {
    final List<Widget> widgets = [];

    for (int i = 0; i < itemCount; i++) {
      widgets.add(itemBuilder(context, i));
      if (i != itemCount - 1 && !disableDivider) {
        widgets.add(Divider(color: themeProviderState.borderColor));
      }
    }
    return widgets;
  }

  @override
  Widget build(BuildContext context) {
    final theme = context.watch<ThemeProvider>().theme;

    return Container(
      padding: padding,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: buildItem(context, theme),
      ),
    );
  }
}
