import 'package:basic_ui/src/providers/theme_provider.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:provider/provider.dart';

import 'basic_appbar.dart';

class BasicTabScaffold extends HookWidget {
  const BasicTabScaffold({
    Key? key,
    this.body,
    this.drawer,
    this.title,
    this.actions,
    this.floatingActionButton,
    this.appBarColor,
    this.enableSearchBar,
    this.searchBarPlaceHolder,
    this.onClear,
    this.onSubmitted,
    required this.tabs,
    required this.tabBarViews,
  }) : super(key: key);

  final Widget? body;
  final Widget? drawer;
  final String? title;
  final List<Widget>? actions;
  final Widget? floatingActionButton;
  final Color? appBarColor;
  final bool? enableSearchBar;
  final String? searchBarPlaceHolder;
  final Function? onClear;
  final Function(String)? onSubmitted;
  final List<Widget> tabs;
  final List<Widget> tabBarViews;

  @override
  Widget build(BuildContext context) {
    final theme = context.watch<ThemeProvider>().theme;

    return DefaultTabController(
      length: tabs.length,
      child: Scaffold(
        backgroundColor: theme.backgroundColor,
        appBar: BasicAppBar(
          title: title ?? "",
          actions: actions,
          backgroundColor: appBarColor,
          enableSearchBar: enableSearchBar ?? false,
          searchBarPlaceHolder: searchBarPlaceHolder,
          onClear: onClear,
          onSubmitted: onSubmitted,
          tabs: tabs,
        ),
        drawer: drawer,
        body: TabBarView(children: tabBarViews),
        floatingActionButton: floatingActionButton,
      ),
    );
  }
}
