import 'package:basic_ui/src/providers/theme_provider.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:provider/provider.dart';

enum BasicTextVariant {
  tiny,
  small,
  medium,
  large,
  xLarge,
  xxLarge,
  mega,
  label
}

class BasicText extends HookWidget {
  const BasicText(
    this.text, {
    Key? key,
    this.variant = BasicTextVariant.medium,
    this.textAlign,
    this.color,
    this.fontWeight,
    this.fontSize,
  }) : super(key: key);

  final String text;
  final BasicTextVariant variant;
  final TextAlign? textAlign;
  final Color? color;
  final FontWeight? fontWeight;
  final double? fontSize;

  double getFontSize() {
    switch (variant) {
      case BasicTextVariant.label:
      case BasicTextVariant.tiny:
        return 13.0;

      case BasicTextVariant.small:
        return 14.0;

      case BasicTextVariant.medium:
        return 16.0;

      case BasicTextVariant.large:
        return 20.0;

      case BasicTextVariant.xLarge:
        return 22.0;

      case BasicTextVariant.xxLarge:
        return 30.0;

      case BasicTextVariant.mega:
        return 70.0;

      default:
        return 16.0;
    }
  }

  FontWeight getFontWeight() {
    switch (variant) {
      case BasicTextVariant.label:
        return FontWeight.w700;

      case BasicTextVariant.xLarge:
        return FontWeight.w600;

      case BasicTextVariant.xxLarge:
        return FontWeight.w600;

      case BasicTextVariant.mega:
        return FontWeight.w600;

      default:
        return FontWeight.w400;
    }
  }

  @override
  Widget build(BuildContext context) {
    final theme = context.watch<ThemeProvider>().theme;

    return Text(
      text,
      style: TextStyle(
        fontWeight: fontWeight ?? getFontWeight(),
        fontSize: fontSize ?? getFontSize(),
        color: color ?? theme.fontColor,
      ),
      textAlign: textAlign,
    );
  }
}
