import 'package:basic_ui/src/providers/theme_provider.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:provider/provider.dart';

import 'basic_text.dart';

class BasicTextField extends HookWidget {
  const BasicTextField({
    Key? key,
    this.label,
    this.defaultValue,
    this.maxLength,
    this.keyboardType,
    this.onChanged,
    this.validator,
    this.isPassword = false,
  }) : super(key: key);

  final String? label;
  final String? defaultValue;
  final int? maxLength;
  final TextInputType? keyboardType;
  final Function(String)? onChanged;
  final String? Function(String?)? validator;
  final bool isPassword;

  @override
  Widget build(BuildContext context) {
    final theme = context.watch<ThemeProvider>().theme;

    final _isPasswordShow = useState(false);
    final controller = useState(TextEditingController());

    useEffect(() {
      controller.value.text = defaultValue ?? "";
    }, []);

    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        if (label != null)
          Padding(
            padding: const EdgeInsets.symmetric(vertical: 5),
            child: BasicText(label!, variant: BasicTextVariant.label),
          ),
        TextFormField(
          textInputAction: TextInputAction.go,
          controller: controller.value,
          onChanged: onChanged,
          enableSuggestions: false,
          autocorrect: false,
          maxLength: maxLength,
          keyboardType: keyboardType,
          validator: validator,
          obscureText: isPassword && !_isPasswordShow.value,
          decoration: InputDecoration(
            isDense: true,
            contentPadding: const EdgeInsets.all(10),
            focusedBorder: OutlineInputBorder(
              borderSide: BorderSide(color: theme.primaryColor, width: 1.5),
              borderRadius: const BorderRadius.all(Radius.circular(3)),
            ),
            enabledBorder: OutlineInputBorder(
              borderSide: BorderSide(color: theme.fontColor),
              borderRadius: const BorderRadius.all(Radius.circular(3)),
            ),
            errorBorder: OutlineInputBorder(
              borderSide: BorderSide(color: theme.dangerColor),
              borderRadius: const BorderRadius.all(Radius.circular(3)),
            ),
            focusedErrorBorder: OutlineInputBorder(
              borderSide: BorderSide(color: theme.dangerColor),
              borderRadius: const BorderRadius.all(Radius.circular(3)),
            ),
            errorStyle: TextStyle(color: theme.dangerColor),
            suffixIcon: InkWell(
              onTap: () {
                if (!isPassword) {
                  controller.value.clear();
                } else {
                  _isPasswordShow.value = !_isPasswordShow.value;
                }
              },
              child: Icon(
                !isPassword
                    ? Icons.close
                    : _isPasswordShow.value
                        ? Icons.visibility_off
                        : Icons.visibility,
                color: theme.fontColor,
              ),
            ),
            suffixIconConstraints:
                const BoxConstraints(minWidth: 39, minHeight: 39),
          ),
          style: const TextStyle(fontSize: 14),
        ),
      ],
    );
  }
}
